@@ -7,11 +7,14 @@ def find():
 		cwd = os.getcwd()
 		for root, dirs, files in os.walk(cwd):
 			for file in files:
-				if file.endswith(".png"):
+				if file.endswith(".PNG" or ".png"):
 					image = file
 		if pyautogui.locateOnScreen(image) != None:
+			found = True
 			print ("True")
 			sleep(0.5)
 		else:
+			found = False
 			print ("False")
-			sleep(0.5)
\ No newline at end of file
+			sleep(0.5)
+find()
\ No newline at end of file
